#!/bin/sh
RED='\033[1;31m'
YELLOW='\033[1;33m'
NC='\033[0m' # No Color

BUILD_DIR=`pwd` > /dev/null
#BUILD_DIR=${BUILD_DIR%/*}

export BUILD_DIR
echo "$BUILD_DIR"

# Get date
if [ -z "$DATE" ]; then
DATE=$(date +"%Y%m%d")
export DATE
echo "DATE=${RED}"$DATE${NC}
fi

# Get driver version
if [ -z "$DRV_VER" ]; then
DRV_VER=$(grep DRIVER_VER ./driver/include/aver_version.h | awk '{print $3}' | sed 's/[="]//g')
export DRV_VER
echo DRV_VER=${RED}${DRV_VER}${NC}
fi

if [ -z "$PLATFORM_VALUE" ]; then
# Choose plateform
echo ${YELLOW}
echo "Please Select Platform"
echo "1. x86/x64"
echo "2. arm for tegra"
echo ${NC}
read PLATFORM_VALUE
export PLATFORM_VALUE
fi

case $PLATFORM_VALUE in
1)
	PLATFORM=x86_x64
	export PLATFORM
	SUFFIX=x86_x64
	export SUFFIX
;;
2)
	PLATFORM=arm_for_tegra
	export PLATFORM
	SUFFIX=tegra
	export SUFFIX
	
	if [ -z "$KHDIR" ]; then
		echo ${YELLOW}
		echo "Please input complie kernel path, example complie kernel path: /usr/src/linux-headers-4.9.140-tegra-ubuntu18.04_aarch64/kernel-4.9/"
		echo ${NC}
		read KHDIR_V
		if [ -n "$KHDIR_V" ]; then
			KHDIR=$KHDIR_V
			export KHDIR
		else
			LINUX_KERNEL=$(uname -r)
			KHDIR=/usr/src/linux-headers-${LINUX_KERNEL}
			export KHDIR
		fi
	fi
;;
*)
	echo "Selected Nothing"
	exit 1
;;
esac

if [ -z "$BOARD_VALUE" ]; then
# Choose board
echo ${YELLOW}
echo "Please Select Capture Card!"
echo "1. cl311mn"
echo "2. cl311m2"
echo "3. cm311h"
echo "4. cn311h"
echo "5. cn312s"
echo "6. cn312m"
echo "7. cl314H1"
echo "8. cl312H1"
echo ${NC}
read BOARD_VALUE
export BOARD_VALUE
fi

case $BOARD_VALUE in
1)
	echo "Selected Capture Card cl311mn"
	BOARD=cl311mn
	BOARD_MARCO=AVER_CARD_CL311MN
;;
2)
	echo "Selected Capture Card cl311m2"
	BOARD=cl311m2
	BOARD_MARCO=AVER_CARD_CL311M2
;;
3)
	echo "Selected Capture Card cm311h"
	BOARD=cx311h
	BOARD_MARCO=AVER_CARD_CM311H
;;
4)
	echo "Selected Capture Card cn311h"
	BOARD=cx311h
	BOARD_MARCO=AVER_CARD_CM311H
;;
5)
	echo "Selected Capture Card cn312s"
	BOARD=cn312s
	BOARD_MARCO=AVER_CARD_CN312S
;;
6)
	echo "Selected Capture Card cn312m"
	BOARD=cn312m
	BOARD_MARCO=AVER_CARD_CN312M
;;
7)
	echo "Selected Capture Card cl314H1"
	BOARD=cx311h
	BOARD_MARCO=AVER_CARD_CM311H
;;
8)
	echo "Selected Capture Card cl312H1"
	BOARD=cx311h
	BOARD_MARCO=AVER_CARD_CM311H
;;
*)
	echo "Selected Nothing"
	exit 1
;;
esac

export BOARD
export BUILD_DIR
export BOARD_MARCO

make -C driver clean
make -C driver
cp driver/$BOARD.ko ./

echo ""
echo ------ Build $BOARD.ko Finished ------
echo ""

