/*===================================================================
 * Copyright(c) AVerMedia TECHNOLOGIES, Inc. 2017
 * All rights reserved
 * =================================================================
 * g_queue.c
 *
 *  Created on: Apr 15, 2017
 *      Author: 
 *      Version:
 * =================================================================
 */
 
#include "g_queue.h"
#include "debug.h"

void init_queue(queue_t *item)
 {
    Xil_AssertVoid(item != NULL);

    item->next= item;
    item->prev = item;
 }

int queue_empty(queue_t *head)
{
    Xil_AssertNonvoid(head != NULL);

    return (head->next == head);
}

void __queue_add(queue_t *new,queue_t *prev,queue_t *next)
{
    Xil_AssertVoid(new != NULL);
    Xil_AssertVoid(prev != NULL);
    Xil_AssertVoid(next != NULL);

    next->prev = new;
    new->next = next;
    new->prev = prev;
    prev->next= new;
 }

void queue_add_tail(queue_t *new, queue_t *head)
{
    Xil_AssertVoid(new != NULL);
    Xil_AssertVoid(head != NULL);

     __queue_add(new, head->prev, head);
} 

void __queue_del(queue_t * prev, queue_t * next)
{
    Xil_AssertVoid(prev != NULL);
    Xil_AssertVoid(next != NULL);
         next->prev = prev;
         prev->next= next;
} 
 
void __queue_del_entry(queue_t *entry)
{
    Xil_AssertVoid(entry != NULL);
    __queue_del(entry->prev, entry->next);
}

void queue_del(queue_t *entry)
{
    Xil_AssertVoid(entry != NULL);

    __queue_del(entry->prev, entry->next);
    entry->next = entry;
    entry->prev = entry;
}


void init_g_queue(g_queue_t *head)
{
    Xil_AssertVoid(head != NULL);

    init_queue(&head->queue);
    head->data=NULL;
}

BOOL_T g_queue_empty(g_queue_t *head)
{
    Xil_AssertNonvoid(head != NULL);

    return queue_empty(&head->queue);
}

void g_queue_add_tail(g_queue_t *new, g_queue_t *head)
{
    Xil_AssertVoid(new != NULL);
    Xil_AssertVoid(head != NULL);

    if(head->data)
    {
        debug_msg("Invalid g_queue head\n");
        return;
    }
     queue_add_tail(&head->queue,&new->queue);
}
 
void g_queue_del(g_queue_t *entry)
{
    Xil_AssertVoid(entry != NULL);

    queue_del(&entry->queue);
}

g_queue_t *g_queue_first_entry(g_queue_t *head)
{
    g_queue_t *item=queue_first_entry_or_null(&head->queue, g_queue_t, queue);
    
    return item;
}

g_queue_t *g_queue_last_entry(g_queue_t *head)
{
    g_queue_t *item=NULL;

    if(!g_queue_empty(head))
    {
        item=queue_last_entry(&head->queue, g_queue_t, queue);
    }
    return item;
}

g_queue_t *g_queue_next_entry(g_queue_t *item)
{
    g_queue_t *next=queue_next_entry(item,queue);
    
    return next;
}
        

         



